@@ -1,4 +1,4 @@
-/* $Id: xfce-rc-simple.c,v 1.12 2004/11/05 17:32:33 benny Exp $ */
+/* $Id: xfce-rc-simple.c,v 1.13 2004/11/18 23:27:57 benny Exp $ */
 /*-
  * Copyright (c) 2003-2004 Benedikt Meurer <benny@xfce.org>
  * All rights reserved.
@@ -50,9 +50,10 @@
 #define PATH_MAX 4096
 #endif
 
-#ifndef LINE_MAX
-#define LINE_MAX 8192
+#ifdef LINE_MAX
+#undef LINE_MAX
 #endif
+#define LINE_MAX 8192
 
 /* name of the NULL group */
 #define NULL_GROUP "[NULL]"
